==> terraform-0.2.10.tgz: terraform-0.2.10/src/TFDialogFill.h <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef _TF_DIALOG_FILL_H
#define _TF_DIALOG_FILL_H


#include "GuiDialogOAC.h"			// includes gtk, gtk--
#include "HeightFieldOps.h"
#include "HeightFieldDraw.h"


/*
 *  TFDialogFill: display the filling dialog for terraformer
 */
class TFDialogFill : public GuiDialogOAC
	{
	public: 
				TFDialogFill (HeightField *HF, HeightFieldDraw *HFD);
				~TFDialogFill (); 
		void		setHFobjs (HeightField *HF, HeightFieldDraw *HFD);
		void		buildDialogWindow ();
		void 		buttonCallbackOK ();
		void 		buttonCallbackApply ();

	private:
		void		fillVBox ();
		gint 		delete_event_impl (GdkEventAny *);

		Gtk_VBox                d_vBoxMain; 
		Gtk_HBox                d_hBoxFillElv, 
					d_hBoxTightFactor,
					d_hBoxKeepMin; 
		Gtk_Adjustment		d_adjFillElv,
					d_adjTightFactor;
		Gtk_HScale 		d_hsFillElv,
					d_hsTightFactor;
		Gtk_Label		d_lblFillElv,
					d_lblTightFactor,
					d_lblKeepMin;
		Gtk_CheckButton		d_cbKeepMin;
		HeightField		*d_HF;
		HeightFieldDraw		*d_HFD;
		HeightFieldOps		*d_HFO;
	};


#endif // _TF_DIALOG_FILL_H

==> terraform-0.2.11.tgz: terraform-0.2.11/src/TFDialogFill.h <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef _TF_DIALOG_FILL_H
#define _TF_DIALOG_FILL_H


#include "GuiDialogPreview.h"			// includes gtk, gtk--
#include "HeightFieldOps.h"
#include "HeightFieldDraw.h"


/*
 *  TFDialogFill: display the filling dialog for terraformer
 */
class TFDialogFill : public GuiDialogPreview
	{
	public: 
				TFDialogFill (HeightField *HF, HeightFieldDraw *HFD);
				~TFDialogFill (); 
		void		setHFobjs (HeightField *HF, HeightFieldDraw *HFD);
		void		buildDialogWindow ();
		void 		buttonCallbackOK ();
		void 		buttonCallbackApply ();

	private:
		void		insertOptions ();
		gint 		delete_event_impl (GdkEventAny *);

		Gtk_VBox                d_vBoxOptions; 
		Gtk_HBox                d_hBoxFillElv, 
					d_hBoxTightFactor,
					d_hBoxKeepMin; 
		Gtk_Adjustment		d_adjFillElv,
					d_adjTightFactor;
		Gtk_HScale 		d_hsFillElv,
					d_hsTightFactor;
		Gtk_Label		d_lblFillElv,
					d_lblTightFactor,
					d_lblKeepMin;
		Gtk_Frame		d_optionsFrame;
		Gtk_CheckButton		d_cbKeepMin;
		HeightField		*d_HF;
		HeightFieldDraw		*d_HFD;
		HeightFieldOps		*d_HFO;
	};


#endif // _TF_DIALOG_FILL_H
